function [warningMessages]=beautifyPlots(figs,varargin)
%figures are stored as a nx2 cell where the first column is the figure
%number, and the second column is a vector of the subplot numbers
%varargin should come in sets of 3
% affected plot, property name, value
%ex, 'alg 1', 'color', 'g'
%ex2,'all', 'xmin','min(x)'  <--some properties can only affect all plots
warningMessages={};
curFigs=findobj('Type','figure');
for i=1:size(figs,1)
    
    if isempty(find(curFigs==figs{i,1}, 1))
        continue;
    end
    
    figure(figs{i,1})
    if ~isempty(figs{i,2})
        subplot(figs{i,2}(1),figs{i,2}(2),figs{i,2}(3))
    end
    
    
    for j=0:length(varargin)/3-1
        curProperty=varargin{3*j+1};
        curSubProperty=varargin{3*j+2};
        curValue=varargin{3*j+3};
        
        
        try
            
            
            if strcmpi(curProperty,'legend')%compare strings ignoring case
                h=legend(gca);
            elseif strcmp(curProperty(1),'!')%~isempty(us)
                curProperty=curProperty(2:end);
                possibleTargets=get(gca,'Children');
                fnd=false;
                for ii=1:length(possibleTargets)
                    h=possibleTargets(ii);
                    if strcmp(curProperty,get(h,'DisplayName'))
                        fnd=true;
                        break;
                    end
                end
                if ~fnd
%                     disp(['fig= ',num2str(figs{i,1}),' subplot= ',num2str(figs{i,2}),': ',curProperty,' not found'])
                    continue;
                end
                if strcmp(get(h,'Type'),'patch') && strcmp(curSubProperty,'Color')
                    curSubProperty = 'FaceColor';
                end
            elseif strcmpi(curProperty,'axis')
                if ~isempty(curSubProperty)
                    [xmin,xmax,ymin,ymax,x,y] = getMaxAndMinValuesOfPlot(gca);
                    curValue=eval(curValue);
                end
                axis(curValue)
                continue;
            elseif strcmpi(curProperty,'XLim') || strcmpi(curProperty,'YLim')
                [xmin,xmax,ymin,ymax,x,y] = getMaxAndMinValuesOfPlot(gca);
                h=gca;
                curSubProperty=curProperty;
                curValue=eval(curValue);
            elseif strcmpi(curProperty,'Title')
                h=get(gca,curProperty);
            elseif isempty(curSubProperty)
                
                curSubProperty=curProperty;
                if strcmpi(curProperty,'Position')
                    h=gcf;
                else
                    h=gca;
                end
                
            else
                h=get(gca,curProperty);
                
            end
            
            
            
            
        catch ME
            %                         ME.getReport
%             warningMessages{end+1}=['Unknown target: ',curProperty];
        end
        
        
        
        
        
        
        try
            set(h,curSubProperty,curValue)
            
        catch ME
%             ME.message
%             ME.getReport
           warningMessages{end+1}=['Bad property: ', curSubProperty, ' or bad value: ',num2str(curValue)];
        end
        
        
        
        
        
        
    end
end
end
function [xmin,xmax,ymin,ymax,x,y] = getMaxAndMinValuesOfPlot(fig)
referencesToLines=findall(fig,'Type','line');
fnd=false;
xmin=inf;
xmax=-inf;
ymax=-inf;
ymin=inf;
for i=1:length(referencesToLines)
    if isempty(get(referencesToLines(i),'DisplayName')) %if the line doesn't have a legend name
        continue;
    end
    fnd=true;
    x=get(referencesToLines(i),'xData');
    y=get(referencesToLines(i),'yData');
    xmin=min(xmin,min(x))-eps; %the plots have a tendancy to cut stuff off, this fixes it
    xmax=max(xmax,max(x))+eps;
    ymax=max(ymax,max(y))+eps;
    ymin=min(ymin,min(y))-eps;
end
if ~fnd
    error('Axis data not found')
end
end

function figure(h)
set(0,'CurrentFigure',h)  %this allows us to change the figure without changing focus
end