function [ U ] = paperV1_mtxGen_diagStacks_sec5p3( m, n, ~, mu )
%PAPERV1_MTXGEN_ DIAGSTACKS_SEC5P3 Returns a m by n matrix U with orthonormal columns and leverage
%scores li.
%
%   [ U ] = paperV1_mtxGen_diagStacks_sec5p3( m, n, [], mu ) Returns a m by n matrix U with
%     orthonormal columns and leverage scores li.  m/n MUST be an integer!
%
%   [ U ] = paperV1_mtxGen_diagStacks_sec5p3( 'info' ) will return data about this matrix generation
%     algorithm, including what what inputs it needs.



if nargin==1
    if strcmp(m,'info');
        U=struct;
        U.plotName='Old diagStacks Sec 5.3';
        U.name='Old Stacks of diagonal matrices (Old Section 5.3)';
        U.inputsNeeded.m=1;
        U.inputsNeeded.n=1;
        U.inputsNeeded.c=0;
        U.inputsNeeded.mu=1;
        U.inputsNeeded.delta=0;
        U.inputsNeeded.li=0;
        U.inputsNeeded.Q=0;
        U.type='mtxGen';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=4
    error('Wrong number of inputs.')
end





if abs((m/n)-round(m/n))> 10^-14
    error('m/n must be an integer')
end
if (m/n)<2
    error('m/n must be at least 2')
end
if n>m
    error('n<=N')
end
if n==1
    error('N>1')
end


% e0=eye(n)/sqrt(mon);   % This is another way to do it
% e1=e0;e1(1,1)=sqrt(mu);
% e2=e0;e2(1,1)=sqrt((1-mu)/(mon-1));

mon=m/n;
e1=eye(n)*sqrt(mu);
e2=eye(n)*sqrt((1-mu)/(mon-1));
U=e1;
for i=1:mon-1
    U=[U;e2];
end



end

