function [ U ] = paperV1_mtxGen_hadStruct_sec5p3( m, n, ~, mu )
%PAPERV1_MTXGEN_HADSTRUCT_SEC5P3 Returns a m by n matrix U with orthonormal columns and leverage
%scores li.
%
%   [ U ] = paperV1_mtxGen_hadStruct_sec5p3( m, n, [], mu ) Returns a m by n matrix U with
%     orthonormal columns and leverage scores li.  m MUST be a power of 2!
%
%   [ U ] = paperV1_mtxGen_hadStruct_sec5p3( 'info' ) will return data about this matrix generation
%     algorithm, including what what inputs it needs.



if nargin==1
    if strcmp(m,'info');
        U=struct;
        U.plotName='Old HadStruct Sec 5.3';
        U.name='Old Matrices with Hadamard structure (Old Section 5.3)';
        U.inputsNeeded.m=1;
        U.inputsNeeded.n=1;
        U.inputsNeeded.c=0;
        U.inputsNeeded.mu=1;
        U.inputsNeeded.delta=0;
        U.inputsNeeded.li=0;
        U.inputsNeeded.Q=0;
        U.type='mtxGen';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=4
    error('Wrong number of inputs.')
end






if abs(log2(m)-round(log2(m)))> 10^-14
    error('N must be a power of 2, it is possible that there are other sizes (like the hadamard mtx), however I dont know how to make them yet')
end
if n>m-1
    error('n<=N')
end
if m==1
    error('N>1')
end
p=round(log2(m));

alpha=sqrt((mu-(n-1)/(m-1))/(1-(n-1)/(m-1)));
beta=sqrt((1-alpha^2)/(m-1));
T_a2=alpha;
T_b2=beta;
T_a=T_a2;
T_b=T_b2;
for j=2:p
    if size(T_a,2)<n
    T_a=[T_a,-T_b;T_b,T_a];
    T_b=[-T_b,T_b;T_b,T_b];
    else
        T_a=[T_a;T_b];%only store the entries we need
        T_b=[-T_b;T_b];
    end
    if size(T_a,2)>n 
        T_a=T_a(:,1:n);
        T_b=T_b(:,1:n);
    end
end
if size(T_a,2)<n
U=[T_a,-T_b;T_b,T_a];
else
    U=[T_a;T_b];
end
if size(T_a,2)>n 
U=U(:,1:n);
else
end

end
