function [ bound ] = paperV1_theoBound4( m, n, c, mu, delta, ~, ~ )
%PAPERV1_THEOBOUND4 Returns a bound for the condition number of SQ.  The bound
%name can be found by running paperV1_theoBound4( 'info' ).
%
%   b = paperV1_theoBound4( m, n, c, mu, delta, li, Q ) returns this bound for
%     the condition number of SQ given the inputs.
%     Inputs:
%        m: Number of rows in Q
%        n: Number of columns in Q
%        c: Number of rows to sample
%        mu: Coherence of Q
%        delta: Failure rate
%        li: Leverage scores of Q
%        Q: The matrix we are testing
%
%   b = paperV1_theoBound4( 'info' ) will return data about this sampling
%     algorithm, including what what inputs it needs.

if nargin==1
    if strcmp(m,'info');
        bound=struct;
        bound.plotName='Old Thm 3.5';
        bound.name='Old Theorem 3.5';
        bound.inputsNeeded.m=1;
        bound.inputsNeeded.n=1;
        bound.inputsNeeded.c=1;
        bound.inputsNeeded.mu=1;
        bound.inputsNeeded.delta=1;
        bound.inputsNeeded.li=0;
        bound.inputsNeeded.Q=0;
        bound.type='Bound';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=7
    error('Wrong number of inputs.')
end
if delta<=0 || delta>=1
    error('invalid delta')
end

epsilon = sqrt((m*n*mu)/c) + m*mu*sqrt(8*log(1/delta)/c);

if epsilon<=0 || epsilon>=1
    bound = 'badEps';
else
    bound=sqrt((1+epsilon)/(1-epsilon));
end
end

