function [ bound ] = paperV1_theoBound6( m, n, c, mu, delta, ~, ~ )
%PAPERV1_THEOBOUND6 Returns a bound for the condition number of SQ.  The bound
%name can be found by running paperV1_theoBound6( 'info' ).
%
%   b = paperV1_theoBound6( m, n, c, mu, delta, li, Q ) returns this bound for
%     the condition number of SQ given the inputs.
%     Inputs:
%        m: Number of rows in Q
%        n: Number of columns in Q
%        c: Number of rows to sample
%        mu: Coherence of Q
%        delta: Failure rate
%        li: Leverage scores of Q
%        Q: The matrix we are testing
%
%   b = paperV1_theoBound6( 'info' ) will return data about this sampling
%     algorithm, including what what inputs it needs.

if nargin==1
    if strcmp(m,'info');
        bound=struct;
        bound.plotName='Old Cor 4.3';
        bound.name='Old Corollary 4.3';
        bound.inputsNeeded.m=1;
        bound.inputsNeeded.n=1;
        bound.inputsNeeded.c=1;
        bound.inputsNeeded.mu=1;
        bound.inputsNeeded.delta=1;
        bound.inputsNeeded.li=0;
        bound.inputsNeeded.Q=0;
        bound.type='Bound';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=7
    error('Wrong number of inputs.')
end
gamma=c/m;
phi = max(1,(1-gamma)/gamma);
l=2/3*log(2*n/delta);
epsilon = mu/2*(phi*l + sqrt(((1-gamma)/gamma)*12*m*l + (phi*l)^2));
% %

if 0<epsilon && epsilon<1
    bound=sqrt((1+epsilon)/(1-epsilon));
else
    bound='badEps';
end

if isequal(c,m)
    bound=1; % if k=m, then all rows are sampled and kappa=1
end
end

