function [ bound ] = paperV1_theoBound8( m, n, c, mu, delta, ~, ~ )
%PAPERV1_THEOBOUND8 Returns a bound for the condition number of SQ.  The bound
%name can be found by running paperV1_theoBound8( 'info' ).
%
%   b = paperV1_theoBound8( m, n, c, mu, delta, li, Q ) returns this bound for
%     the condition number of SQ given the inputs.
%     Inputs:
%        m: Number of rows in Q
%        n: Number of columns in Q
%        c: Number of rows to sample
%        mu: Coherence of Q
%        delta: Failure rate
%        li: Leverage scores of Q
%        Q: The matrix we are testing
%
%   b = paperV1_theoBound8( 'info' ) will return data about this sampling
%     algorithm, including what what inputs it needs.

if nargin==1
    if strcmp(m,'info');
        bound=struct;
        bound.plotName='Old Thm 4.5';
        bound.name='Old Theorem 4.5';
        bound.inputsNeeded.m=1;
        bound.inputsNeeded.n=1;
        bound.inputsNeeded.c=1;
        bound.inputsNeeded.mu=1;
        bound.inputsNeeded.delta=1;
        bound.inputsNeeded.li=0;
        bound.inputsNeeded.Q=0;
        bound.type='Bound';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=7
    error('Wrong number of inputs.')
end
if delta<=0 || delta>=1
    error('invalid delta')
end

gamma=c/m;


OptimOptions = optimset('Display','off', 'TolFun',delta*10^-30);
epsilon = fminsearch(@(x) (geTodelta(m,n,gamma,mu,x)-delta)^2,0, OptimOptions); %we find the min value of y
if epsilon<=0 || epsilon>=1%make sure epsilon is of an acceptable value
    bound = 'badEps';
else
    if abs(delta-geTodelta(m,n,gamma,mu,epsilon))/delta<10^-12 %double check answer,  I have an error tolerance for delta which I hardcoded to appear on the plot.
        bound=sqrt((1+epsilon)/(1-epsilon));
    else
        bound='badEps';
    end
end
end
function delta = geTodelta(~,n,gamma,mu,epsilon)%THIS is the delta function from bound8
delta = n*((exp(-epsilon)*(1-epsilon)^(epsilon-1))^(gamma/mu) + (exp(epsilon)*(1+epsilon)^(-epsilon-1))^(gamma/mu));
end

