function [ li ] = paperV2_liDist_oneBig( m,n,mu )
%PAPERV2_LIDIST_ONEBIG Returns a leverage score distribution with only one large
%leverage score for a m by n matrix with coherence mu.
%
%   li = paperV2_liDist_oneBig( m, n, mu ) Returns a leverage score distribution
%     with only one large leverage score for a m by n matrix with coherence
%     mu.
%
%   li = paperV2_liDist_oneBig( 'info' ) will return data about this leverage score
%     distribution function, including what what inputs it needs.

if nargin==1
    if strcmp(m,'info');
        li=struct;
        li.plotName='Alg 6.2';
        li.name='One large leverage score (Alg 6.2)';
        li.inputsNeeded.m=1;
        li.inputsNeeded.n=1;
        li.inputsNeeded.c=0;
        li.inputsNeeded.mu=1;
        li.inputsNeeded.delta=0;
        li.inputsNeeded.li=0;
        li.inputsNeeded.Q=0;
        li.type='liDist';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=3
    error('Wrong number of inputs.')
end
    if mu<n/m || mu>1
        error('mu must satisfy n/m<=mu<=1')
    end
    
    li=[mu; ones(m-1,1)*(n-mu)/(m-1) ];
    
end

