function [ U ] = paperV2_mtxGen_li( m, n, li, ~ )
%PAPERV2_MTXGEN_LI Returns a m by n matrix U with orthonormal columns and leverage
%scores li.
%
%   [ U ] = paperV2_mtxGen_li( m, n, li ) Returns a m by n matrix U with
%     orthonormal columns and leverage scores li.
%
%   [ U ] = paperV2_mtxGen_li( 'info' ) will return data about this matrix generation
%     algorithm, including what what inputs it needs.



%Generates a mXn matrix of with leverage scores z
if nargin==1
    if strcmp(m,'info');
        U=struct;
        U.plotName='6.1';
        U.name='Matrix Generation Alg 6.1';
        U.inputsNeeded.m=1;
        U.inputsNeeded.n=1;
        U.inputsNeeded.c=0;
        U.inputsNeeded.mu=0;
        U.inputsNeeded.delta=0;
        U.inputsNeeded.li=1;
        U.inputsNeeded.Q=0;
        U.type='mtxGen';
        return;
    else
        error('Wrong number of inputs.')
    end
elseif nargin~=4
    error('Wrong number of inputs.')
end

if abs(sum(li)-n)>eps*m*4
    error('leverage scores must sum to n')
end
if length(li)~=m
    error('you need m leverage scores')
end
if min(size(li))~=1
    error('leverage scores must be a vector')
end
if m<n
    error('We must have m>=n')
end

wtBrMtx=waitbar(0,'Generating Matrix, Estimated Time Left: calculating');

U=zeros(m,n);U(m-n+1:m,1:n)=eye(n);%initial matrix
[li,I]=sort(li);%desired leverage scores sorted, remember I for later
a=zeros(1,m);a(m-n+1:m)=1;
j=m-n+1;
i=m-n;

%---Waitbar Code---
tic;
dneI=1000;
oldTime=toc;
%------------------

for ii=1:m-1
    
    %---Waitbar Code---
    if  ii>dneI || toc>oldTime+10%%%%This if statement is for the progress bar
        ttt=toc/(ii-1)*(m-ii-2);
        if ttt>3600
            tLeft=[num2str(ttt/3600),' hours'];
        elseif ttt>60
            tLeft=[num2str(ttt/60),' minutes'];
        else
            tLeft=[num2str(ttt),' seconds'];
        end
        oldTime=toc;
        waitbar(ii/(m-1),wtBrMtx,['Generating Matrix, Estimated Time Left: ',tLeft])
        %             waitbar(ii/(m-1),wtBrMtx)
        dneI=dneI+(m-1)/100;
    end
    %------------------
    
    if i<1 || j>m
        break;%sometimes we finish early
    end
    
    %rotate rows
    if -(a(i)-li(i))<(a(j)-li(j))
        [c,s] = DiffcsSol(U,i,j,li(i));
        U([i j],:) = [c s;-s c]*U([i j],:);
    else
        [c,s] = DiffcsSol(U,j,i,li(j));
        U([j i],:) = [c s;-s c]*U([j i],:);
    end
    
    a(i) = U(i,:)*U(i,:)';
    a(j) = U(j,:)*U(j,:)';
    
    if abs(a(i)-li(i))<10^-15
        i=i-1;%we are done with this small row
    end
    if abs(a(j)-li(j))<10^-15
        j=j+1; %we are done with this big row
    end
end

U(I,:)=U;%sort U such that leverage sores are in the correct order

%---Waitbar Code---
delete(wtBrMtx)
%------------------

end

function [c,s]=DiffcsSol(A,i,j,nom)%I previously verified that this is solvable
%here I use the method from dhillon and tropp to solve
a=A(i,:)';
aa=a'*a;
b=A(j,:)';
bb=b'*b;ab=a'*b;
tmp1=-ab/(bb-nom);
tmp2=(sqrt(ab^2-(aa-nom)*(bb-nom)))/(bb-nom);%we define these variables to avoid sign cancellations.
if tmp1<=0%For numerical stability
    tp=tmp1 - tmp2;
else
    tp=tmp1+tmp2;
end
c=1/sqrt(1+tp^2);
s=c*tp;
end
