function [ out_internal ] = condCheck( vN_internal, vNVS_internal, iC_internal, varargin )
%CONDCHECK will return the value of eval( vNVS_internal ) if
%the input conditions in the string iC_internal are satisfied. If they are
%not satisfied, condCheck will throw an error.
%
%   [ out ] = condCheck( vN, vNVS, iC)
%
%   Inputs:
%
%   vN: A string which should contain the name of the
%   variable, hereafter referred to as VAR, that we wish to evaluate
%
%   vNVS: A string which should contain the values
%   which should be assigned to VAR
%
%   iC: A string which should contain the conditions
%   that VAR must satisfy. If no conditions are required, then set
%   iC_internal = ''.
%
%   Outputs:
%
%   out: The values which should be assigned to VAR.
%
%   [ out ] = condCheck( vN, vNVS, iC, y1Name, y1Val, ...)
%
%   Optional Inputs:
%
%   y1Name: A string which contain the name of an additional variable which
%   will be passed to the function
%
%   y1Val: The value of y1Name
%
%   Example Uses:
%
%   x = condCheck('x','1:5','max(x)<10')
%   will set x = 1:5 because max(x)<10 is true
%
%   x = condCheck('x','1:5','max(x)<2')
%   will throw an error because max(x)<10 is false
%
%   x = condCheck('x','1:y','max(x)<10','y',5)
%   will set x = 1:5 because y=5, and max(x)<10 is true
%
%   x = condCheck('x','1:y','max(x)<z','y',5,'z',2)
%   will set throw an error because y=5 and max(x)<z is false
%
%   Note: We have apended "_internal" to the end of all internal variables
%   to ensure that they are not the same as any variable names that the
%   user has passed to this function.

if nargin > 3 %we have additional variables which we would like to pass into the function
    if mod(length(varargin),2) % We must have an even number of entries in varargin (pairs of variable names and values)
        error('condCheck requires 3 + 2*n inputs')
    end
    
    for i_internal = 1:2:length(varargin)
        eval([varargin{i_internal} '= varargin{',num2str(i_internal),'+1};']) %create the given variables in this workspace
    end
    
elseif nargin < 3
    error('condCheck requires 3 + 2*n inputs')
end


try
    eval([vN_internal, '=', vNVS_internal, ';']) %create the variable we are checking
catch
    error(['Error defining ',vN_internal,', please fix ',vN_internal]);
end

if ~isempty(iC_internal)
    try
        eval(['if ~(',iC_internal,'); error(''problem''); end;'])
    catch ME_internal
        if ~strcmp(ME_internal.message,'problem')
            error(['Error checking conditions for ', vN_internal,': ', ME_internal.message])
        else
            error(['You must satisfy: ',iC_internal,', please fix ',vN_internal,'.']);
        end
    end
    
end

eval(['out_internal =', vN_internal,';']) %return the evaluated value of vN_internal

end

