function [ inputsNeeded, fromFileYN ] = getInputsNeeded( handles )
%GETINPUTSNEEDED returns the inputs that are needed for the current
%experiments and bounds and whether or not we are loading information from
%a file.  This is an internal function only meant to be used by the
%kappa_SQ package.
%
%   [ inputsNeeded, fromFileYN ] = getInputsNeeded( handles ) inputs the
%   handle for the kappa_SQ gui and returns what inputs are currently
%   needed to run all of the experiements and bounds.  It will also return
%   whether or not the user has decided to load a matrix from a file.
%

%Start off assuming that we don't need anything, and that we are not
%loading a file.
inputsNeeded.m=0;
inputsNeeded.n=0;
inputsNeeded.c=0;
inputsNeeded.mu=0;
inputsNeeded.delta=0;
inputsNeeded.li=0;
inputsNeeded.Q=0;
inputsNeeded.runs=0;%we don't load this one from files
fromFileYN=0;
flNames={};


%Load list of bound fn-files that the user wants to run
bndSelections=get(handles.boundListbox,'Value');
if ~isempty(bndSelections)
    flNames=[flNames handles.boundFlNm(bndSelections)];
end

%Load list of experiment fn-files that the user wants to run
expSelections=get(handles.experimentListbox,'Value');
if ~isempty(expSelections)
    inputsNeeded.runs=1;
    flNames=[flNames handles.expFlNm(expSelections)];
end

%The ability to select a leverage score distribution or a matrix generation
%algorithm depends on whether or not we need Q.  We don't want to
%accidentally load default values, so we will first determine if Q is
%needed
%we have to run this first to see if we need li or Q
for i=1:length(flNames)
    if strcmp(flNames{i},'From File')
        fromFileYN=1;
        continue
    end
    curInfo=eval([flNames{i} '(''info'');']);
    if curInfo.inputsNeeded.m
        inputsNeeded.m=1;
    end
    if curInfo.inputsNeeded.n
        inputsNeeded.n=1;
    end
    if curInfo.inputsNeeded.c
        inputsNeeded.c=1;
    end
    if curInfo.inputsNeeded.mu
        inputsNeeded.mu=1;
    end
    if curInfo.inputsNeeded.delta
        inputsNeeded.delta=1;
    end
    if curInfo.inputsNeeded.li
        inputsNeeded.li=1;
    end
    if curInfo.inputsNeeded.Q
        inputsNeeded.Q=1;
    end
end

flNames={};%We don't need to recheck these files


if inputsNeeded.Q  %If this is not ture, then the user cannot see mtxGenInput selections
    mtxGenSelections=get(handles.mtxGenInput,'Value');
    if ~isempty(mtxGenSelections)
        flNames=[flNames handles.mtxGenFlNm(mtxGenSelections)];
    end
    %we may now need li, we must check for this
    
    for i=1:length(flNames)
        if strcmp(flNames{i},'From File')
            fromFileYN=1;
            continue
        end
        curInfo=eval([flNames{i} '(''info'');']);
        if curInfo.inputsNeeded.m
            inputsNeeded.m=1;
        end
        if curInfo.inputsNeeded.n
            inputsNeeded.n=1;
        end
        if curInfo.inputsNeeded.c
            inputsNeeded.c=1;
        end
        if curInfo.inputsNeeded.mu
            inputsNeeded.mu=1;
        end
        if curInfo.inputsNeeded.delta
            inputsNeeded.delta=1;
        end
        if curInfo.inputsNeeded.li
            inputsNeeded.li=1;
        end
        if curInfo.inputsNeeded.Q
            inputsNeeded.Q=1;
        end
    end
    
    flNames={};%we don't need to check the old file names again
    
end



%Load list of liDist fn-files that the user wants to run (if enabled)
if inputsNeeded.li
    liSelections=get(handles.liDistInput,'Value');
    if ~isempty(liSelections)
        flNames=[flNames handles.liDistFlNm(liSelections)];
    end
    for i=1:length(flNames)
        if strcmp(flNames{i},'From File')
            fromFileYN=1;
            continue
        end
        curInfo=eval([flNames{i} '(''info'');']);
        if curInfo.inputsNeeded.m
            inputsNeeded.m=1;
        end
        if curInfo.inputsNeeded.n
            inputsNeeded.n=1;
        end
        if curInfo.inputsNeeded.c
            inputsNeeded.c=1;
        end
        if curInfo.inputsNeeded.mu
            inputsNeeded.mu=1;
        end
        if curInfo.inputsNeeded.delta
            inputsNeeded.delta=1;
        end
        if curInfo.inputsNeeded.li
            inputsNeeded.li=1;
        end
        if curInfo.inputsNeeded.Q
            inputsNeeded.Q=1;
        end
    end
end



if inputsNeeded.li
    inputsNeeded.mu=1; %mu comes from li
end


end

