


%This  script is run by kappa_SQ_v2.m  It is run inside of a try-catch
%statement, so all errors are sent to a message window.  When something is
%wrong we will throw an error.

%We will only send error messages to the command window and create an error
%dump if a serious error has occured.
seriousError=false;

%Get which inputs are needed and whether or not we are loading from a file
[ inputsNeeded, fromFileYN ] = getInputsNeeded( handles );

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Get Initial variables and check that they meet certain requierements. %
%If an initial variable is not needed we will set it as Undefined ([]).%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

expList=handles.expFlNm;%list of experiments that can be run
expChoice=get(handles.experimentListbox,'Value');%the experiments that will be run

boundList=handles.boundFlNm;%list of bounds that can be run
boundChoice=get(handles.boundListbox,'Value');%the bounds that will be run

mtxMethodList=handles.mtxGenFlNm;%list of mtx gen methods that can be run
mtxMethodChoice=get(handles.mtxGenInput,'Value');%the mtx gen method that will be used

plotConfInt=get(handles.plotConfIntChk,'Value');  %Do you want to plot confidence intervals

if plotConfInt %This is a little bit expensive, so we only do it if we have to.
    impConf=get(handles.impConfCheckBox,'Value');
else
    impConf=false;
end

%Due to the limited numer of symbols and the fact that we want our plots to
%be in black and white (for publishing) we limit the user to 5 bounds and 3
%experiments.

if length(boundChoice)>5
    error('Please select no more than 5 bounds.')
end
if length(expChoice)>3
    error('please select no more tha 3 experiments.')
end
if isempty(expChoice) && isempty(boundChoice)
    error('Nothing selected.')
end
if fromFileYN
    
    flName=handles.matFlNm{get(handles.matFileListbox,'Value')};
    A=load(flName);
    A=eval(['A.',get(handles.varNameInput,'String')]); %A is a matrix
    [m,n]=size(A);
    mStr=num2str(m);
    nStr=num2str(n);
    mtxMStr=[flName,' >> ', get(handles.varNameInput,'String')];
    if inputsNeeded.li || inputsNeeded.mu
        [li, A]=leverageScores(A);
        mu=max(li);
        liStr=[flName,' >> ', get(handles.varNameInput,'String')];
        muStr=num2str(mu);
    else
        li=[];
        mu=[];
        [~, A]=leverageScores(A);  %this finds an orthonormal basis for A if A does not already have orthonormal columns
        liStr='Undefined';
        muStr='Undefined';
    end
    
else
    
    if inputsNeeded.m && inputsNeeded.n
        mStr = get(handles.mInput,'String');
        nStr = get(handles.nInput,'String');
        
        try %we don't know if the user defined m in terms of n, or n in terms of m
            m = condCheck('m',mStr, 'm>0 && ~mod(m,1) && length(m)==1');
            n = condCheck('n',nStr, 'n>0 && m>n && ~mod(n,1) && length(n)==1', 'm',m);
        catch
            n = condCheck('n',nStr, 'n>0 && ~mod(n,1) && length(n)==1');
            m = condCheck('m',mStr, 'm>0 && m>n && ~mod(m,1) && length(m)==1', 'n',n);
        end
    else
        error('One of the selected Bound or Exp. should require m or n')
        %This program was designed for the case where m>n, you must do something that requires m and n
    end
    
    if inputsNeeded.mu
        muStr = get(handles.muInput,'String');
        mu = condCheck('mu',muStr,'min(mu)>=n/m && max(mu)<=1', 'm',m,'n',n);
        mu = sort(mu(:))'; %make mu have ascending order
    else
        mu=[];
        muStr='Undefined';
    end
    
    if inputsNeeded.li
        liStr = handles.liDistFlNm{get(handles.liDistInput,'Value')};
        if length(mu)>1
            if isequal('fromFile',liStr)
                error('mu must be a scalar when loading from a file.')
            end
            li = eval(['@',liStr]); %li is a function to be called later
            
        else

            li = eval([liStr,'(m,n,mu)']);
        end
        
    else
        li=[];
        liStr='Undefined';
    end
end

if inputsNeeded.c
    cStr = get(handles.cInput,'String');
    c = condCheck('c',cStr, 'min(c)>=n && max(c)<=m && max(abs(mod(c,1)))==0','m',m,'n',n);
    c = sort(c(:))'; %make c have ascending order
else
    cStr='Undefined';
    c=[];
end

if inputsNeeded.delta
    deltaStr = get(handles.deltaInput,'String');
    delta = condCheck('delta',deltaStr,' delta>0 && delta<1');
else
    deltaStr='Undefined';
    delta=[];
end

if inputsNeeded.runs
    runsStr = get(handles.runsInput,'String');
    runs = condCheck('runs',runsStr,'length(runs)==1 && ~mod(runs,1) && runs>0');
    failConfidenceStr = get(handles.failConfidenceInput, 'String');
    failConfidence = condCheck('failConfidence', failConfidenceStr, 'failConfidence<=1 && failConfidence >=0 && length(failConfidence)==1');
else
    runsStr='Undefined';
    runs=[];
    failConfidenceStr='Undefined';
    failConfidence = [];
end

%The program allows the user to put either mu or c on the x-axis.  The term
%that the user wants on the x-axis should be a vector and the other should
%be a scalar.

if length(mu)>1
    xAxisType=1;%x axis is mu
else
    xAxisType=2;%x axis is c
end

if length(mu)>1 && length(c)>1
    error('Either c is a vector and mu is a scalar, or vise-versa')
end

%If we are not loading from a file, but we need the matrix, we must
%generate it.

if ~fromFileYN && inputsNeeded.Q
    if xAxisType==1
        %If mu is the x-axis, then we cannot generate the matrix here (we
        %will need one for each mu value).  A is defined to be a function
        %that will return the desired matrix.
        A=eval(['@',mtxMethodList{mtxMethodChoice}]);%we will compute the matrix later, NOTE: A is a FUNCTION!
    else
        %if x is the x-axis, then weonly need to generate the matrix once,
        %and we will do that here.
        [A]=eval([mtxMethodList{mtxMethodChoice},'(m,n,li,mu);']);%Generate matrix
    end
    mtxMStr=mtxMethodList{mtxMethodChoice};
elseif ~inputsNeeded.Q
    %If we don't need A, we define it to be an empty matrix.
    A=[];
    mtxMStr='Undefined';
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Start to run experiments and collect data.                            %
%All important data will be stored in the plotData struct              %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%If an error occurs after this point, something serious went wrong and we
%should should give the full error report.
seriousError=true;

plotData=struct([]);%holds all of our plot data

%For plotting, we will want to store some min and max values
ymax=-inf;
xmax=-inf;
xmin=inf;

%We don't store data if an expriment yeilded no results (all sampled
%matrices were rank deficient, or the conditions for our bounds failed).

expAndBounds = [ expList(expChoice), boundList(boundChoice) ];
noDataCount=0;%the index of plotData we will access

for i=1:length(expAndBounds)
    curName = expAndBounds{i};
    theoFnOrSampleType=eval(['@',curName]);
    fnGet=eval([curName,'(''info'')']);
    
    if i <= length(expChoice) %we are doing an experiment
        [xAxis,data, xfailureP,failureP, failConfidenceTopBottom] = dataCollector(m,n,runs,c, mu, li, xAxisType , A, theoFnOrSampleType, ['Working on (',fnGet.plotName,')'], failConfidence, impConf );
        curTypeStr='experiment';
    else                      %we are doing a bound
        [ xAxis, data ] = theoDataCollector( m, n, c, mu, li, A, delta, xAxisType , theoFnOrSampleType, ['Working on (',fnGet.plotName,')'] );
        curTypeStr='bound';
    end
    
    if isempty(data)   %we will only store the run if there is something to plot.
        noDataCount=noDataCount+1;
        continue;
    end
    
    j=i-noDataCount;
    
    ymax=max(ymax,max(data));
    xmax=max(xmax,max(xAxis));
    xmin=min(xmin,min(xAxis));
    plotData(j).plotName=fnGet.plotName;
    plotData(j).name=fnGet.name;
    plotData(j).fileUsed=[curName,'.m'];
    plotData(j).plT=curTypeStr;
    plotData(j).m=m;
    plotData(j).n=n;
    plotData(j).c=c;
    plotData(j).mu=mu;
    plotData(j).mtxM=mtxMStr;
    plotData(j).liFunc=liStr;
    plotData(j).xAxis=xAxis;
    plotData(j).data=data;
    
    
    if i <= length(expChoice) %we are doing an experiment
        plotData(j).xfailureP=xfailureP;
        plotData(j).failureP=failureP;
        plotData(j).delta=[];
        plotData(j).runs=runs;
        plotData(j).failConfidene=failConfidence*100;
        plotData(j).failConfideneHighLow=failConfidenceTopBottom;
        plotData(j).improveConfInterval=impConf;
    else                      %we are doing a bound
        plotData(j).xfailureP=[];
        plotData(j).failureP=[];
        plotData(j).delta=delta;
        plotData(j).runs=[];
        plotData(j).failConfidene=[];
        plotData(j).failConfideneHighLow=[];
    end
    
    %CLEAR ALL PERSISTENT VARIABLES. This is very important. Some
    %functions may use persistent variables for quantities that are
    %expensive to compute. We must delete these before moving onto the next
    %experiment.
    Vars=whos;
    PersistentVars=Vars(([Vars.global] &...
        ~strcmp({Vars.name},'eventdata') &...
        ~strcmp({Vars.name},'hObject') &...
        ~strcmp({Vars.name},'handles')));%persistent and not wtBr, handles, hObject, or eventdata
    PersistentVarNames={PersistentVars.name};
    if ~isempty(PersistentVarNames)
        clear(PersistentVarNames{:});
    end
    
    
end

if isempty(plotData)
    seriousError=false;
    error('None of your experiments or bounds produced data.  Try different inputs.')
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Start plotting section.                                               %
%All data has been collected                                           %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%plot styles
plotCStringsT=cell(0);
plotCStringsT{1}='b^';
plotCStringsT{2}='bs';
plotCStringsT{3}='b+';

plotCStringsT2=cell(0);
plotCStringsT2{1}='b^-';
plotCStringsT2{2}='bs-';
plotCStringsT2{3}='b+-';
errColor=[.7 .7 .85];

plotCStrings=cell(0);
plotCStrings{1}='r-';
plotCStrings{2}='r:';
plotCStrings{3}='r-.';
plotCStrings{4}='r--';
plotCStrings{5}='r-*';

%begin constructing plot, label, cells and title string
if ~isempty(strfind(liStr,'From file'))
    liPlotStr=plotData(1).liFunc;%this is constant for all plotData
elseif strcmp('Undefined',liStr)
    liPlotStr='Undf';
else
    liPlotStr=eval([liStr,'(''info'')']);liPlotStr=liPlotStr.plotName;
end
if ~isempty(strfind(mtxMStr,'From file'))
    mtxMPlotStr=plotData(1).mtxM;
elseif strcmp('Undefined',mtxMStr)
    mtxMPlotStr='Undf';
else
    mtxMPlotStr=eval([mtxMStr,'(''info'')']);mtxMPlotStr=mtxMPlotStr.plotName;
end

plot1Cell={};
plot2Cell={};
errCell={};
legend1Cell={};
legend2Cell={};
legend2ErrCell={};
title1Str=['m=',mStr,', n=',nStr,', c=',cStr,', mu=',muStr,', delta=',deltaStr,', runs=',runsStr,'\newlineli=',liPlotStr,'\newlinemtxM=',mtxMPlotStr];
title2Str=['Failure Probability: ',title1Str];
if xAxisType==1
    xlblStr='mu';%ADD XLABEL
elseif xAxisType==2
    xlblStr='c';%ADD XLABEL
end
areThereExperiments=false;
plotSymbolExpIdx=1;
plotSymbolBoundIdx=1;

for i=1:length(plotData)%create cells for plotting
    if strcmp(plotData(i).plT,'experiment'); %remember, experiments come first
        areThereExperiments=true;
        plot1Cell{1,i} = plotData(i).xAxis; %remember, matlab uses pointers
        plot1Cell{2,i} = plotData(i).data;
        plot1Cell{3,i} = plotCStringsT{plotSymbolExpIdx};
        legend1Cell{i} = plotData(i).plotName;
        
        plot2Cell{1,i} = plotData(i).xfailureP; %remember, matlab uses pointers
        plot2Cell{2,i} = plotData(i).failureP;
        plot2Cell{3,i} = plotCStringsT2{plotSymbolExpIdx};
        
        
        errCell{1,i} = [plotData(i).xfailureP  fliplr(plotData(i).xfailureP)];
        errCell{2,i} = [plotData(i).failConfideneHighLow(2,:)  fliplr(plotData(i).failConfideneHighLow(1,:))];
        errCell{3,i} = errColor;
        
        legend2Cell{i} = plotData(i).plotName;
        legend2ErrCell{i} = [plotData(i).plotName,' ',num2str(plotData(i).failConfidene),'%'];
        plotSymbolExpIdx=plotSymbolExpIdx+1;
        
    else  %remember, experiments come first, we won't have empty columns
        plot1Cell{1,i} = plotData(i).xAxis; %remember, matlab uses pointers
        plot1Cell{2,i} = plotData(i).data;
        plot1Cell{3,i} = plotCStrings{plotSymbolBoundIdx};
        
        legend1Cell{i} = plotData(i).plotName;
        
        plotSymbolBoundIdx=plotSymbolBoundIdx+1;
        
        
    end
    
    
end
if plotConfInt
legend2Cell=[legend2ErrCell legend2Cell];
end
if xmin==xmax
    xmax=xmin+10^-15;
end
if ymax==1
    ymax=ymax+10^-15;
end
FS=15;
titleFS=8;
try
    figure(1)
    clf
    semilogy(plot1Cell{:},'LineWidth',2);
    legend(legend1Cell{:});
    title(title1Str, 'FontSize', titleFS);
    xlabel(xlblStr, 'FontSize', FS);
    ylabel('\kappa(SQ)', 'FontSize', FS);
    axis([xmin xmax 1 ymax])
    
    if areThereExperiments
        figure(2)
        clf
        hold on
        if plotConfInt
        fill(errCell{:});
        end
        plot(plot2Cell{:},'LineWidth',2);
        
        legend(legend2Cell{:});
        title(title2Str, 'FontSize', titleFS);
        xlabel(xlblStr, 'FontSize', FS);
        ylabel('Failure %', 'FontSize', FS);
        axis([xmin xmax 0 100])
        
        figure(3)
        clf
        subplot(2,1,1)
        semilogy(plot1Cell{:},'LineWidth',2);
        legend(legend1Cell{:});
        title(title1Str, 'FontSize', titleFS);
        xlabel(xlblStr, 'FontSize', FS);
        ylabel('\kappa(SQ)', 'FontSize', FS);
        axis([xmin xmax 1 ymax])
        
        subplot(2,1,2)
        hold on
        if plotConfInt
        fill(errCell{:});
        end
        plot(plot2Cell{:},'LineWidth',2);
        
        legend(legend2Cell{:});
        title(title2Str, 'FontSize', titleFS);
        xlabel(xlblStr, 'FontSize', FS);
        ylabel('Failure %', 'FontSize', FS);
        axis([xmin xmax 0 100])
    end
catch
    error('Plotting Error.')
end

if get(handles.saveCheckbox,'Value')  %Save the data if requested
    pause(.001);%The almost always ensures that our filename isn't used
    saveName=[ datestr(now, 'HH.MM.SS.FFF_dd.mm.yyyy'),'_kSQ_data.mat'];
    save(saveName,'plotData');
    set(handles.warningBox,'String',['File saved as: ',saveName]) %Tell the user the filename
end